@@ -3,24 +3,26 @@
 #' These functions modify terminal branches or drop certain terminal branches
 #' based on various criteria.
 
-#' \code{DropZLB} drops tip-taxa that are attached to the tree via zero-length
-#' terminal branches ("ZLBs"). This is sometimes useful for paleo-trees, as
-#' various time-scaling methods often produce these ZLBs, taxa whose early
+#' \code{dropZLB} drops tip-taxa that are attached to the tree via 
+#' zero-length terminal branches ("ZLBs"). 
+#' This is sometimes useful for phylogenies of fossil taxa, as
+#' various time-scaling methods often produce these 'ZLBs', taxa whose early
 #' appearance causes them to be functionally interpreted as ancestors in some
-#' time-scaling methods. Removing ZLBs is advised for analyses of
+#' time-scaling methods. Removing 'ZLBs' is advised for analyses of
 #' diversification/diversity, as these will appear as simultaneous
 #' speciation/extinction events. Note this function only drops tips attached to
 #' a terminal zero-length branch; if you want to collapse internal zero-length
 #' branches, see the ape function \code{\link{di2multi}}.
 #' 
-#' \code{DropExtinct} drops all terminal branches which end before the modern (i.e.
+#' \code{dropExtinct} drops all terminal branches which end before the modern (i.e.
 #' extinct taxa). \code{DropExtant} drops all terminal branches which end at the
 #' modern (i.e. extant/still-living taxa). In both cases, the modern is defined
 #' based on \code{tree$root.time} if available, or the modern is inferred to be the
 #' point in time when the tip furthest from the root (the latest tip)
 #' terminates.
 #' 
-#' If the input tree has a \code{$root.time} element, as expected for most paleo-tree
+#' If the input tree has a \code{$root.time} element,
+#' as expected for most phylogeny containing fossil taxa
 #' objects handled by this library, that \code{$root.time} is adjusted if the relative
 #' time of the root divergence changes when terminal branches are dropped.
 #' This is typically performed via the function \code{\link{fixRootTime}}.
@@ -36,9 +38,9 @@
 #' so the root.time elements in the result tree may
 #' be nonsensical, particularly if negative amounts are input.
 #' 
-#' \code{dropPaleoTip} is a wrapper for ape's \code{\link{drop.tip}} which also modifies the
+#' \code{dropPaleoTip} is a wrapper for \code{ape}'s \code{\link{drop.tip}} which also modifies the
 #' \code{$root.time} element if necessary, using \code{fixRootTime}. Similarly,
-#' bindPaleoTip is a wrapper for phytool's \code{bind.tip} which allows tip age
+#' \code{bindPaleoTip} is a wrapper for phytool's \code{bind.tip} which allows tip age
 #' as input and modifies the \code{$root.time} element if necessary (i.e. if a tip
 #' is added to edge leading up to the root).
 #' 
@@ -54,7 +56,8 @@
 
 #' @aliases dropZLB dropExtinct dropExtant addTermBranchLength 
 
-#' @param tree A phylogeny as a phylo object. \code{dropPaleoTip} requires this
+#' @param tree A phylogeny, as an object of class \code{phylo}.
+#' \code{dropPaleoTip} requires this
 #' input object to also have a \code{tree$root.time} element. If not provided for
 #' \code{bindPaleoTip}, then the \code{$root.time} will be presumed to be such that the
 #' furthest tip from the root is at \code{time = 0}.
@@ -70,7 +73,7 @@
 
 #' @param addtime Extra amount of time to add to all terminal branch lengths.
 
-#' @param ... additional arguments passed to dropPaleoTip are passed to \code{\link{drop.tip}}.
+#' @param ... additional arguments passed to \code{dropPaleoTip} are passed to \code{\link{drop.tip}}.
 
 #' @param tipLabel A character string of \code{length = 1} containing the name of the new tip
 #' to be added to \code{tree}.
@@ -82,11 +85,11 @@
 #' @param edgeLength The new \code{edge.length} of the terminal branch this tip is connected to.
 #' Cannot be given if \code{tipAge} is given. 
 
-#' @param nodeAttach Node or tip ID number (as given in tree$edge) at which to attach the new tip. 
+#' @param nodeAttach Node or tip ID number (as given in \code{tree$edge}) at which to attach the new tip. 
 #' See documentation of \code{bind.tip} for more details.
 
 #' @param positionBelow The distance along the edge below the node to be attached to 
-#' (given in code{nodeAttach} to add the new tip. Cannot be negative or greater than the length of the
+#' (given in \code{nodeAttach} to add the new tip. Cannot be negative or greater than the length of the
 #' edge below \code{nodeAttach}.
 
 #' @param noNegativeEdgeLength Return an error if a negative terminal edge length is calculated
@@ -105,24 +108,36 @@
 #' @examples
 #' 
 #' set.seed(444)
-#' #Simulate some fossil ranges with simFossilRecord
-#' record <- simFossilRecord(p = 0.1, q = 0.1, nruns = 1,
-#' 	nTotalTaxa = c(30,40), nExtant = 0)
+#' # Simulate some fossil ranges with simFossilRecord
+#' record <- simFossilRecord(
+#'     p = 0.1, q = 0.1, 
+#'     nruns = 1, 
+#'     nTotalTaxa = c(30,40), 
+#'     nExtant = 0
+#'     )
 #' taxa <- fossilRecord2fossilTaxa(record)
-#' #simulate a fossil record with imperfect sampling with sampleRanges
+#' # simulate a fossil record 
+#'     # with imperfect sampling with sampleRanges
 #' rangesCont <- sampleRanges(taxa,r = 0.5)
-#' #Now let's make a tree using taxa2phylo
+#' # Now let's make a tree using taxa2phylo
 #' tree <- taxa2phylo(taxa,obs_time = rangesCont[,2])
-#' #compare the two trees
+#' # compare the two trees
 #' layout(1:2)
 #' plot(ladderize(tree))
 #' plot(ladderize(dropZLB(tree)))
+#' 
+#' # reset
 #' layout(1)
 #' 
-#' #example using dropExtinct and dropExtant
+#' 
+#' # example using dropExtinct and dropExtant
 #' set.seed(444)
-#' record <- simFossilRecord(p = 0.1, q = 0.1, nruns = 1,
-#' 	nTotalTaxa = c(30,40), nExtant = c(10,20))
+#' record <- simFossilRecord(
+#'     p = 0.1, q = 0.1, 
+#'     nruns = 1, 
+#'     nTotalTaxa = c(30,40), 
+#'     nExtant = c(10,20)
+#'     )
 #' taxa <- fossilRecord2fossilTaxa(record)
 #' tree <- taxa2phylo(taxa)
 #' phyloDiv(tree)
@@ -131,22 +146,21 @@
 #' tree2 <- dropExtant(tree)
 #' phyloDiv(tree2)
 #' 
-#' #graphics.off()
 #' 
-#' #example using addTermBranchLength
+#' # example using addTermBranchLength
 #' set.seed(444)
 #' treeA <- rtree(10)
 #' treeB <- addTermBranchLength(treeA,1)
 #' compareTermBranches(treeA,treeB)
 #' 
 #' #########################
-#' #test dropPaleoTip
-#' 	#(and fixRootTime by extension...)
+#' # test dropPaleoTip
+#' 	# (and fixRootTime by extension...)
 #' 
-#' #simple example
+#' # simple example
 #' tree <- read.tree(text = "(A:3,(B:2,(C:5,D:3):2):3);")
 #' tree$root.time <- 10
-#' plot(tree,no.margin = FALSE)
+#' plot(tree, no.margin = FALSE)
 #' axisPhylo()
 #' 
 #' # now a series of tests, dropping various tips
@@ -160,74 +174,110 @@
 #' (test[8] <- dropPaleoTip(tree,c("A","D"))$root.time) #  = 7
 #' 
 #' # is it all good? if not, fail so paleotree fails...
-#' if(!identical(test,c(7,10,10,10,5,10,7,7))){stop("fixRootTime fails!")}
+#' if(!identical(test,c(7,10,10,10,5,10,7,7))){
+#'      stop("fixRootTime fails!")
+#'      }
 #' 
 #' 
 #' ##############
-#' #testing bindPaleoTip
+#' # testing bindPaleoTip
 #' 
 #' # simple example 
 #' tree <- read.tree(text = "(A:3,(B:2,(C:5,D:3):2):3);")
 #' tree$root.time <- 20
-#' plot(tree,no.margin = FALSE)
+#' plot(tree, no.margin = FALSE)
 #' axisPhylo()
 #' 
 #' \dontrun{
 #' 
 #' require(phytools)
 #' 
-#' #bindPaleoTip effectively wraps bind.tip from phytools
+#' # bindPaleoTip effectively wraps bind.tip from phytools
 #' # using a conversion like below
 #' 
 #' tipAge <- 5
 #' node <- 6
 #' 
-#' #new length = the root time - tipAge - nodeheight(tree,node)
+#' # the new tree length (tip to root depth) should be:
+#' # new length = the root time - tipAge - nodeheight(tree,node)
 #' 
 #' newLength <- tree$root.time-tipAge-nodeheight(tree,node)
-#' tree1 <- bind.tip(tree,"tip.label",where = node,edge.length = newLength)
+#' tree1 <- bind.tip(tree,
+#'     "tip.label",
+#'     where = node,\
+#'     edge.length = newLength)
 #' 
 #' layout(1:2)
-#' plot(tree);axisPhylo()
-#' plot(tree1);axisPhylo()
+#' plot(tree)
+#' axisPhylo()
+#' plot(tree1)
+#' axisPhylo()
+#' 
+#' # reset
+#' layout(1)
 #' 
 #' }
 #' 
 #' # now with bindPaleoTip
 #' 
-#' 
 #' tree1 <- bindPaleoTip(tree,"new",nodeAttach = 6,tipAge = 5)
 #' 
 #' layout(1:2)
-#' plot(tree);axisPhylo()
-#' plot(tree1);axisPhylo()
+#' plot(tree)
+#' axisPhylo()
+#' plot(tree1)
+#' axisPhylo()
+#' 
+#' # reset
 #' layout(1)
 #' 
 #' #then the tip age of "new" should 5
 #' test <- dateNodes(tree1)[which(tree1$tip.label == "new")] == 5
-#' if(!test){stop("bindPaleoTip fails!")}
+#' if(!test){
+#'     stop("bindPaleoTip fails!")
+#'     }
 #' 
 #' # with positionBelow
 #' 
-#' tree1 <- bindPaleoTip(tree,"new",nodeAttach = 6,tipAge = 5,positionBelow = 1)
+#' tree1 <- bindPaleoTip(
+#'     tree,
+#'     "new",
+#'     nodeAttach = 6,
+#'     tipAge = 5,
+#'     positionBelow = 1
+#'     )
 #' 
 #' layout(1:2)
-#' plot(tree);axisPhylo()
-#' plot(tree1);axisPhylo()
+#' plot(tree)
+#' axisPhylo()
+#' plot(tree1)
+#' axisPhylo()
+#' 
+#' # reset
 #' layout(1)
 #' 
 #' # at the root
 #' 
-#' tree1 <- bindPaleoTip(tree,"new",nodeAttach = 5,tipAge = 5)
+#' tree1 <- bindPaleoTip(
+#'     tree,
+#'     "new", 
+#'     nodeAttach = 5,
+#'     tipAge = 5)
 #' 
 #' layout(1:2)
-#' plot(tree);axisPhylo()
-#' plot(tree1);axisPhylo()
+#' plot(tree)
+#' axisPhylo()
+#' plot(tree1)
+#' axisPhylo()
+#' 
+#' # reset
 #' layout(1)
 #' 
 #' #then the tip age of "new" should 5
 #' test <- dateNodes(tree1)[which(tree1$tip.label == "new")] == 5
-#' if(!test){stop("bindPaleoTip fails!")}
+#' if(!test){
+#'      stop("bindPaleoTip fails!")
+#'      }
 #' 
 #' # at the root with positionBelow
 #' 
@@ -235,15 +285,21 @@
 #' 	positionBelow = 3)
 #' 
 #' layout(1:2)
-#' plot(tree);axisPhylo()
-#' plot(tree1);axisPhylo()
+#' plot(tree)
+#' axisPhylo()
+#' plot(tree1)
+#' axisPhylo()
+#' 
+#' # reset
 #' layout(1)
 #' 
 #' #then the tip age of "new" should 5
 #' test <- dateNodes(tree1)[which(tree1$tip.label == "new")] == 5
 #' #and the root age should be 23
 #' test1 <- tree1$root.time == 23
-#' if(!test | !test1){stop("bindPaleoTip fails!")}
+#' if(!test | !test1){
+#'      stop("bindPaleoTip fails!")
+#'      }
 #' 
 
 
@@ -274,10 +330,13 @@ dropZLB <- function(tree){
 	
 #' @rdname modifyTerminalBranches
 #' @export
-dropExtinct <- function(tree,tol = 0.01,ignore.root.time = FALSE){
-	#drop all terminal taxa that are less than 0.001 from the modern
-	#require(ape)
-	#checks
+dropExtinct <- function(tree,
+                        tol = 0.01,
+                        ignore.root.time = FALSE
+                        ){
+	# drop all terminal taxa that are less than 0.001 from the modern
+	# require(ape)
+	# checks
 	if(!inherits(tree,"phylo")){
 		stop("tree must be of class 'phylo'")
 		}
@@ -287,15 +346,21 @@ dropExtinct <- function(tree,tol = 0.01,ignore.root.time = FALSE){
 	dnode <- node.depth.edgelength(tree)[1:Ntip(tree)]
 	dnode <- round(dnode,6)
 	if(!is.null(tree$root.time) & !ignore.root.time){
-		if(round(tree$root.time,6)>max(dnode)){
-		stop("all tips are extinct based on tree$root.time!")}}
+	    if(round(tree$root.time,6)>max(dnode)){
+	        stop("all tips are extinct based on tree$root.time!")
+	        }
+	    }
 	droppers <- which((dnode+tol)<max(dnode))
-	if((Ntip(tree)-length(droppers))<2){stop("Less than 2 tips are extant on the tree!")}
+	if((Ntip(tree)-length(droppers))<2){
+	    stop("Less than 2 tips are extant on the tree!")
+	    }
 	stree <- drop.tip(tree,droppers)
 	if(!is.null(tree$root.time)){
-		#now need to add $root.time given the droppers
-		#should be root.time MINUS distance from furthest tip in tree PLUS distance from latest tip to root of stree
-		#stree$root.time <- tree$root.time-max(dnode)+max(dist.nodes(stree)[1:Ntip(stree),Ntip(stree)+1])
+		# now need to add $root.time given the droppers
+		# should be root.time MINUS distance from
+	     # furthest tip in tree PLUS distance from latest tip to root of stree
+		# stree$root.time <- tree$root.time - max(dnode)
+	      # + max(dist.nodes(stree)[1:Ntip(stree),Ntip(stree)+1])
 		stree <- fixRootTime(treeOrig = tree, treeNew = stree)
 		}
 	return(stree)
