@@ -7,21 +7,22 @@
 #' 
 #' @details
 #' This function is essentially a wrapper for the individual diversity curve
-#' functions included in paleotree. multiDiv will intuitively decide whether
+#' functions included in paleotree. \code{multiDiv} will intuitively decide whether
 #' input datasets are continuous-time taxic ranges, discrete-time (binned
 #' interval) taxic ranges or phylogenetic trees, as long as they are formatted
 #' as required by the respective diversity curve functions. A list that
-#' contains a mix of data types is entirely acceptable. A list of matrices
-#' output from \code{fossilRecord2fossilTaxa}, via simulation with \code{simFossilRecord}
-#' is allowable, and treated as input for \code{taxicDivCont}.
+#' contains a mix of data types is entirely acceptable.
+#' A list of matrices output from \code{fossilRecord2fossilTaxa},
+#' via simulation with \code{simFossilRecord} is allowable,
+#' and treated as input for \code{taxicDivCont}.
 #' Data of an unknown type gives back an error.
 #' 
-#' The argument split.int splits intervals, if and only if discrete interval
-#' time data is included among the datasets. See the help file for taxicDivDisc
+#' The argument \code{split.int} splits intervals, if and \emph{only} if discrete interval
+#' time data is included among the datasets. See the help file for \code{taxicDivDisc}
 #' to see an explanation of why \code{split.int = TRUE} by default is probably a good
 #' thing.
 #' 
-#' As with many functions in the paleotree library, absolute time is always
+#' As with many functions in the \code{paleotree} library, absolute time is always
 #' decreasing, i.e. the present day is zero.
 #' 
 #' The 'averaged' curve is actually the median rather than the mean as
@@ -41,26 +42,26 @@
 
 #' @param plot If \code{TRUE}, the median diversity curve is plotted.
 
-#' @param results The output of a previous run of multiDiv for replotting.
+#' @param results The output of a previous run of \code{multiDiv} for replotting.
 
 #' @param plotMultCurves If \code{TRUE}, each individual diversity curve is plotted
-#' rather than the median diversity curve and 95 percent quantiles. FALSE by
-#' default.
+#' rather than the median diversity curve and 95 percent quantiles. 
+#' \code{plotMultCurves = FALSE} by default.
 
-#' @param yAxisLims Limits for the y (i.e. richness) axis on the plotted diversity curves. Only
-#' affects plotting. Given as either NULL (the default) or as a vector of
-#' length two as for \code{xlim} in the basic R function \code{plot}. Time axes 
-#' will be plotted \emph{exactly} to these values. The minimum value must be more than 1 if
-#' \code{plotLogRich = TRUE}.
+#' @param yAxisLims Limits for the y (i.e. richness) axis on the plotted diversity curves. 
+#' Only affects plotting. Given as either \code{NULL} (the default) or as a vector of
+#' length two as for \code{xlim} in the basic R function \code{plot}. 
+#' Time axes will be plotted \emph{exactly} to these values. 
+#' The minimum value must be more than 1 if \code{plotLogRich = TRUE}.
 
-#' @param multRainbow If \code{TRUE} and plotMultCurves are both \code{TRUE}, each line is
-#' plotted as a different, randomized color using the function 'rainbow'. If
-#' FALSE, each line is plotted as a black line. This argument is ignored if
-#' divPalette is supplied.
+#' @param multRainbow If \code{TRUE} and \code{plotMultCurves = TRUE}, each line is
+#' plotted as a different, randomized color using the function \code{rainbow}. If
+#' \code{FALSE}, each line is plotted as a black line. This argument is ignored if
+#' \code{divPalette} is supplied.
 
 #' @param divPalette Can be used so users can pass a vector of chosen color
-#' identifiers for each diversity curve in 'data' which will take precedence
-#' over multRainbow. Must be the same length as the number of diversity curves
+#' identifiers for each diversity curve in \code{data} which will take precedence
+#' over \code{multRainbow}. Must be the same length as the number of diversity curves
 #' supplied.
 
 #' @param divLineType Used to determine line type (\code{lty}) of the
@@ -81,56 +82,17 @@
 #' @seealso The diversity curve functions used include: \code{\link{phyloDiv}},
 #' \code{\link{taxicDivCont}} and \code{\link{taxicDivDisc}}.
 #' 
-#' Also see the function LTT.average.root in the package TreeSim, which
+#' Also see the function \code{LTT.average.root} in the package \code{TreeSim}, which
 #' calculates an average LTT curve for multiple phylogenies, the functions
-#' code{mltt.plot} in ape and code{ltt} in phytools.
+#' \code{mltt.plot} in ape and \code{ltt} in \code{phytools}.
 
 #' @examples
+#' # let's look at this function
+#'     # with some birth-death simulations
 #' 
 #' set.seed(444)
-#' record <- simFossilRecord(
-#'     p = 0.1, q = 0.1, 
-#'     nruns = 1,
-#'     nTotalTaxa = c(30,40), 
-#'     nExtant = 0)
-#' taxa <- fossilRecord2fossilTaxa(record)
-#' rangesCont <- sampleRanges(taxa, r = 0.5)
-#' rangesDisc <- binTimeData(rangesCont, int.length = 1)
-#' cladogram <- taxa2cladogram(taxa, plot = TRUE)
-#' #using multiDiv with very different data types
-#' ttree <- timePaleoPhy(
-#'     cladogram, 
-#'     rangesCont, 
-#'     type = "basic", 
-#'     add.term = TRUE, 
-#'     plot = FALSE
-#'     )
-#'     
-#' input <- list(rangesCont, rangesDisc, ttree)
-#' multiDiv(input, plot = TRUE)
 #' 
-#' #using fixed interval times
-#' multiDiv(input, 
-#'     int.times = rangesDisc[[1]], 
-#'     plot = TRUE)
-#' 
-#' #using multiDiv with samples of trees
-#' ttrees <- timePaleoPhy(
-#'     cladogram, 
-#'     rangesCont, 
-#'     type = "basic",
-#'     randres = TRUE, 
-#'     ntrees = 10, 
-#'     add.term = TRUE
-#'     )
-#'     
-#' multiDiv(ttrees)
-#'     
-#' # uncertainty in diversity history is solely due to 
-#'    # the random resolution of polytomies
-#' 
-#' ################
-#' # multiDiv can also take output from simFossilRecord
+#' # multiDiv can take output from simFossilRecord
 #'     # via fossilRecord2fossilTaxa
 #' 
 #' # what do many simulations run under some set of
@@ -144,17 +106,17 @@
 #'     plot = TRUE
 #'     )
 #' 
-#' taxa <- sapply(records, fossilRecord2fossilTaxa)
+#' taxa <- lapply(records, fossilRecord2fossilTaxa)
 #' 
 #' multiDiv(taxa)
-#' #increasing cone of diversity! 
+#' # increasing cone of diversity! 
 #' 
-#' #Its even better on a log scale:
+#' # Its even better on a log scale:
 #' multiDiv(taxa, plotLogRich = TRUE)
 #' 
 #' #######################################
-#' #pure-birth example with simFossilRecord
-#' #note that conditioning is tricky
+#' # pure-birth example with simFossilRecord
+#' # note that conditioning is tricky
 #' 
 #' set.seed(444)
 #' recordsPB <- simFossilRecord(
@@ -165,11 +127,11 @@
 #'     plot = TRUE
 #'     )
 #'     
-#' taxaPB <- sapply(recordsPB, fossilRecord2fossilTaxa)
+#' taxaPB <- lapply(recordsPB, fossilRecord2fossilTaxa)
 #' multiDiv(taxaPB, plotLogRich = TRUE)
 #' 
 #' #compare many discrete diversity curves
-#' discreteRanges <- lapply(taxa, function(x)
+#' discreteRanges <- lapply(taxaPB, function(x)
 #'     binTimeData(
 #'         sampleRanges(x, 
 #'             r = 0.5,
@@ -180,6 +142,62 @@
 #' 
 #' multiDiv(discreteRanges)
 #' 
+#' #########################################
+#' # plotting a multi-diversity curve for
+#'    # a sample of stochastic dated trees
+#' 
+#' record <- simFossilRecord(
+#'     p = 0.1, q = 0.1, 
+#'     nruns = 1,
+#'     nTotalTaxa = c(30,40), 
+#'     nExtant = 0)
+#'     
+#' taxa <- fossilRecord2fossilTaxa(record)
+#' rangesCont <- sampleRanges(taxa, r = 0.5)
+#' rangesDisc <- binTimeData(rangesCont,
+#'     int.length = 1)
+#' # get the cladogram
+#' cladogram <- taxa2cladogram(taxa, plot = TRUE)
+#' 
+#' #using multiDiv with samples of trees
+#' ttrees <- timePaleoPhy(
+#'     cladogram, 
+#'     rangesCont, 
+#'     type = "basic",
+#'     randres = TRUE, 
+#'     ntrees = 10, 
+#'     add.term = TRUE
+#'     )
+#'     
+#' multiDiv(ttrees)
+#' 
+#' # uncertainty in diversity history is solely due to 
+#'     # the random resolution of polytomies
+#' 
+#' ######################################################### 
+#' 
+#' #using multiDiv to compare very different data types:
+#'    # continuous ranges, discrete ranges, dated tree
+#' 
+#' # get a single dated tree
+#' ttree <- timePaleoPhy(
+#'     cladogram, 
+#'     rangesCont, 
+#'     type = "basic", 
+#'     add.term = TRUE, 
+#'     plot = FALSE
+#'     )
+#'     
+#' # put them altogether in a list
+#' input <- list(rangesCont, rangesDisc, ttree)
+#' 
+#' multiDiv(input, plot = TRUE)
+#' 
+#' # what happens if we use fixed interval times?
+#' multiDiv(input, 
+#'     int.times = rangesDisc[[1]], 
+#'     plot = TRUE)
+#' 
 #' layout(1)
 #' 
 
@@ -219,31 +237,47 @@ multiDiv <- function(
 	#int.length = 1;plot = TRUE;split.int = TRUE;drop.ZLB = TRUE;drop.cryptic = FALSE;plotLogRich = FALSE;timeLims = NULL
 	#plotMultCurves = FALSE;multRainbow = TRUE;divPalette = NULL
 	#require(ape)
-	dclass <- sapply(data,class)	#data classes
-	dclass1 <- numeric(length(dclass));dclass1[dclass == "matrix"] <- 1;
-		dclass1[dclass == "list"] <- 2;dclass1[dclass == "phylo"] <- 3
-	if(any(dclass1 == 0)){stop("Data of Unknown Type")}
+	#
+  # identify class of data
+  # data classes
+  dataClassType <- sapply(data, function(x){
+    classType <- NA
+    if(inherits(x = x, what = "matrix")){
+      classType <- 1
+      }
+    if(inherits(x = x, what = "list")){
+      classType <- 2
+      }  
+    if(inherits(x = x, what = "phylo")){
+      classType <- 3
+      }
+    if(is.na(classType)){
+      stop("Data of unknown type - not a matrix, list or phylogeny?")
+      }
+    return(classType)
+    })
+  # 
 	if(is.null(int.times)){
 		tblen <- int.length
 		#get max and min times for each type
-		if(any(dclass1 == 1)){
-			lims1 <- sapply(data[dclass1 == 1],function(x) 
+		if(any(dataClassType == 1)){
+			lims1 <- sapply(data[dataClassType == 1],function(x) 
 				if(ncol(x) == 6){
 					c(min(x[,3:4],na.rm = T),max(x[,3:4],na.rm = T))	
 				}else{
 					c(min(x,na.rm = TRUE),max(x,na.rm = TRUE))}
 				)
 		}else{lims1 <- NA}
-		if(any(dclass1 == 2)){	
-			for(i in which(dclass1 == 2)){
+		if(any(dataClassType == 2)){	
+			for(i in which(dataClassType == 2)){
 				data[[i]][[1]][data[[i]][[1]][,1] == 0,1] <- extant.adjust
 				}
-			lims2 <- sapply(data[dclass1 == 2],function(x) 
+			lims2 <- sapply(data[dataClassType == 2],function(x) 
 				c(min(x[[1]][max(x[[2]]),]),max(x[[1]][min(x[[2]]),])))
 		}else{lims2 <- NA}
-		if(any(dclass1 == 3)){
+		if(any(dataClassType == 3)){
 			lims3 <- numeric()
-			for(i in which(dclass1 == 3)){
+			for(i in which(dataClassType == 3)){
 				ttree <- data[[i]]
 				if(is.null(ttree$root.time)){
 					ntime <- node.depth.edgelength(ttree)
@@ -261,8 +295,9 @@ multiDiv <- function(
 		midtimes <- midtimes[midtimes>0]
 		int.start <- midtimes+(tblen/2);int.end <- midtimes-(tblen/2)
 		int.times <- cbind(int.start,int.end)
-		if(split.int & any(dclass1 == 2)){
-			#for every single discrete time dataset, bins must be split at their boundaries
+		if(split.int & any(dataClassType == 2)){
+			# for every single discrete time dataset
+		      # bins must be split at their boundaries
 			splinters <- sapply(data[dclasss = 2],function(x) x[[1]][,1])
 			mustSplit <- apply(int.times, 1,
 				function(x) any(sapply(splinters,function(y) x[1]>y & x[2]<y))
@@ -290,7 +325,7 @@ multiDiv <- function(
 		}			
 	div <- matrix(,nrow(int.times),1)
 	for(i in 1:length(data)){
-		if((dclass1[i] == 1)){
+		if((dataClassType[i] == 1)){
 			divs1 <- taxicDivCont(
 				timeData = data[[i]],
 				int.times = int.times,
@@ -300,7 +335,7 @@ multiDiv <- function(
 			divs1 <- divs1[,3]
 			div <- cbind(div,divs1)
 			}
-		if((dclass1[i] == 2)){
+		if((dataClassType[i] == 2)){
 			divs2 <- taxicDivDisc(
 				timeList = data[[i]],
 				int.times = int.times,
@@ -310,7 +345,7 @@ multiDiv <- function(
 			divs2 <- divs2[,3]
 			div <- cbind(div,divs2)
 			}
-		if((dclass1[i] == 3)){
+		if((dataClassType[i] == 3)){
 			divs3 <- phyloDiv(
 				tree = data[[i]],
 				int.times = int.times,
@@ -359,9 +394,18 @@ multiDiv <- function(
 
 #' @rdname multiDiv
 #' @export	
-plotMultiDiv <- function(results,plotLogRich = FALSE,timelims = NULL,
-		yAxisLims = NULL,plotMultCurves = FALSE,
-		multRainbow = TRUE,divPalette = NULL,divLineType = 1,main = NULL){
+plotMultiDiv <- function(
+      results, 
+      plotLogRich = FALSE, 
+      timelims = NULL, 
+      yAxisLims = NULL, 
+      plotMultCurves = FALSE, 
+      multRainbow = TRUE,
+      divPalette = NULL,
+      divLineType = 1,
+      main = NULL
+      ){
+  ####################
 	if(!is.null(timelims)){
 		if(length(timelims) != 2){
 			stop("if given, timelims should be a vector of length 2")
@@ -375,18 +419,19 @@ plotMultiDiv <- function(results,plotLogRich = FALSE,timelims = NULL,
 			stop("if richness is plotted on a log scale, minimum axis value must be  >= 1")
 			}
 		}
-	#plots the median diversity curve for a multiDiv() result
+	# plots the median diversity curve for a multiDiv() result
 	int.start <- results[[1]][,1]
 	int.end <- results[[1]][,2]
 	times1 <- c(int.start,(int.end+((int.start-int.end)/10000)))
 	if(plotMultCurves){
 		if(is.null(main)){
 			main <- "Multiple Diversity Curves"
-			}
-		divs <- results[[2]]	#here's my div information
+		  }
+	  # here's my diversity information
+		divs <- results[[2]]	
 		divs1 <- rbind(divs,divs)[order(times1),]
 		times1 <- sort(times1)
-		#set up the general plotting window
+		# set up the general plotting window
 		if(plotLogRich){
 			if(is.null(yAxisLims)){
 				y_lim <- c(min(divs1[divs1 >= 1]),max(divs1[divs1 >= 1]))
