@@ -58,4 +58,9 @@ hundredRandomlySelectedTrees <- obtainDatedPosteriorTreesMrB(
 	outputTrees = 100, 
 	file = NULL)
 
+testthat::skip_on_cran()
+testthat::skip_on_travis()	
+expect_equal_to_reference(hundredRandomlySelectedTrees, update=TRUE,
+	file = ".//references//datedPosteriorTreesMrB//hundredRandom") 
+
 })
\ No newline at end of file
